Installation
============

You may use pip to install the latest version of envanter:

.. code-block:: bash

    $ python -m pip install envanter

Visit `envanter on PyPI <https://pypi.org/project/envanter/>`_
